@@ -1,20 +1,21 @@
 <?php
 
+namespace SimpleSAML\Stats;
 
 /**
  * Interface for statistics outputs.
  *
  * @package SimpleSAMLphp
  */
-abstract class SimpleSAML_Stats_Output
-{
 
+abstract class Output
+{
     /**
      * Initialize the output.
      *
-     * @param SimpleSAML_Configuration $config The configuration for this output.
+     * @param \SimpleSAML\Configuration $config The configuration for this output.
      */
-    public function __construct(SimpleSAML_Configuration $config)
+    public function __construct(\SimpleSAML\Configuration $config)
     {
         // do nothing by default
     }
