@@ -35,8 +35,8 @@ class Net
         list ($net, $mask) = explode('/', $cidr);
         $mask = intval($mask);
 
-        $ip_ip = array();
-        $ip_net = array();
+        $ip_ip = [];
+        $ip_net = [];
         if (strstr($ip, ':') || strstr($net, ':')) {
             // Validate IPv6 with inet_pton, convert to hex with bin2hex
             // then store as a long with hexdec
