@@ -1,12 +1,15 @@
 <?php
 
+namespace SimpleSAML\XHTML;
+
 /**
  * A minimalistic Emailer class. Creates and sends HTML emails.
  *
  * @author Andreas kre Solberg, UNINETT AS. <andreas.solberg@uninett.no>
  * @package SimpleSAMLphp
  */
-class SimpleSAML_XHTML_EMail
+
+class EMail
 {
     private $to = null;
     private $cc = null;
@@ -14,7 +17,7 @@ class SimpleSAML_XHTML_EMail
     private $from = null;
     private $replyto = null;
     private $subject = null;
-    private $headers = array();
+    private $headers = [];
 
 
     /**
@@ -41,7 +44,7 @@ class SimpleSAML_XHTML_EMail
 
     /*
      * @param string $body
-     * @return void
+     * @return string
      */
     private function getHTML($body)
     {
@@ -65,7 +68,7 @@ pre {
 </head>
 <body>
 <div class="container" style="background: #fafafa; border: 1px solid #eee; margin: 2em; padding: .6em;">
-' . $body . '
+'.$body.'
 </div>
 </body>
 </html>';
@@ -78,45 +81,45 @@ pre {
     public function send()
     {
         if ($this->to === null) {
-            throw new Exception('EMail field [to] is required and not set.');
+            throw new \Exception('EMail field [to] is required and not set.');
         } elseif ($this->subject === null) {
-            throw new Exception('EMail field [subject] is required and not set.');
+            throw new \Exception('EMail field [subject] is required and not set.');
         } elseif ($this->body === null) {
-            throw new Exception('EMail field [body] is required and not set.');
+            throw new \Exception('EMail field [body] is required and not set.');
         }
 
         $random_hash = bin2hex(openssl_random_pseudo_bytes(16));
 
         if (isset($this->from)) {
-            $this->headers[]= 'From: ' . $this->from;
+            $this->headers[] = 'From: '.$this->from;
         }
         if (isset($this->replyto)) {
-            $this->headers[]= 'Reply-To: ' . $this->replyto;
+            $this->headers[] = 'Reply-To: '.$this->replyto;
         }
 
-        $this->headers[] = 'Content-Type: multipart/alternative; boundary="simplesamlphp-' . $random_hash . '"';
+        $this->headers[] = 'Content-Type: multipart/alternative; boundary="simplesamlphp-'.$random_hash.'"';
 
         $message = '
---simplesamlphp-' . $random_hash . '
+--simplesamlphp-'.$random_hash.'
 Content-Type: text/plain; charset="utf-8" 
 Content-Transfer-Encoding: 8bit
 
-' . strip_tags(html_entity_decode($this->body)) . '
+'.strip_tags(html_entity_decode($this->body)).'
 
---simplesamlphp-' . $random_hash . '
+--simplesamlphp-'.$random_hash.'
 Content-Type: text/html; charset="utf-8" 
 Content-Transfer-Encoding: 8bit
 
-' . $this->getHTML($this->body) . '
+'.$this->getHTML($this->body).'
 
---simplesamlphp-' . $random_hash . '--
+--simplesamlphp-'.$random_hash.'--
 ';
         $headers = implode("\n", $this->headers);
 
         $mail_sent = @mail($this->to, $this->subject, $message, $headers);
-        SimpleSAML\Logger::debug('Email: Sending e-mail to [' . $this->to . '] : ' . ($mail_sent ? 'OK' : 'Failed'));
+        \SimpleSAML\Logger::debug('Email: Sending e-mail to ['.$this->to.'] : '.($mail_sent ? 'OK' : 'Failed'));
         if (!$mail_sent) {
-            throw new Exception('Error when sending e-mail');
+            throw new \Exception('Error when sending e-mail');
         }
     }
 }
