@@ -8,8 +8,8 @@
  */
 
 /*
-$metadata['theproviderid-of-the-idp'] = array(
-	'SingleSignOnService'  => 'https://idp.example.org/shibboleth-idp/SSO',
-	'certificate'          => 'example.pem',
-);
+$metadata['theproviderid-of-the-idp'] = [
+    'SingleSignOnService' => 'https://idp.example.org/shibboleth-idp/SSO',
+    'certificate' => 'example.pem',
+];
 */
