@@ -1,4 +1,7 @@
 <?php
+
+namespace SimpleSAML\Module\core\Auth\Process;
+
 /**
  * Filter to modify attributes using regular expressions
  *
@@ -7,7 +10,8 @@
  * @author Jacob Christiansen, WAYF
  * @package SimpleSAMLphp
  */
-class sspmod_core_Auth_Process_AttributeAlter extends SimpleSAML_Auth_ProcessingFilter
+
+class AttributeAlter extends \SimpleSAML\Auth\ProcessingFilter
 {
     /**
      * Should the pattern found be replaced?
@@ -44,7 +48,7 @@ class sspmod_core_Auth_Process_AttributeAlter extends SimpleSAML_Auth_Processing
      *
      * @param array $config  Configuration information about this filter.
      * @param mixed $reserved  For future use.
-     * @throws SimpleSAML_Error_Exception In case of invalid configuration.
+     * @throws \SimpleSAML\Error\Exception In case of invalid configuration.
      */
     public function __construct($config, $reserved)
     {
@@ -61,7 +65,7 @@ class sspmod_core_Auth_Process_AttributeAlter extends SimpleSAML_Auth_Processing
                 } elseif ($value === '%remove') {
                     $this->remove = true;
                 } else {
-                    throw new SimpleSAML_Error_Exception('Unknown flag : ' . var_export($value, true));
+                    throw new \SimpleSAML\Error\Exception('Unknown flag : '.var_export($value, true));
                 }
                 continue;
             } elseif ($name === 'pattern') {
@@ -86,31 +90,32 @@ class sspmod_core_Auth_Process_AttributeAlter extends SimpleSAML_Auth_Processing
      * Modify existing attributes with the configured values.
      *
      * @param array &$request The current request.
-     * @throws SimpleSAML_Error_Exception In case of invalid configuration.
+     * @throws \SimpleSAML\Error\Exception In case of invalid configuration.
      */
-    public function process(&$request) {
+    public function process(&$request)
+    {
         assert(is_array($request));
         assert(array_key_exists('Attributes', $request));
 
         // get attributes from request
-        $attributes =& $request['Attributes'];
+        $attributes = &$request['Attributes'];
 
         // check that all required params are set in config
         if (empty($this->pattern) || empty($this->subject)) {
-            throw new SimpleSAML_Error_Exception("Not all params set in config.");
+            throw new \SimpleSAML\Error\Exception("Not all params set in config.");
         }
 
         if (!$this->replace && !$this->remove && $this->replacement === false) {
-            throw new SimpleSAML_Error_Exception("'replacement' must be set if neither '%replace' nor ".
+            throw new \SimpleSAML\Error\Exception("'replacement' must be set if neither '%replace' nor ".
                 "'%remove' are set.");
         }
 
         if (!$this->replace && $this->replacement === null) {
-            throw new SimpleSAML_Error_Exception("'%replace' must be set if 'replacement' is null.");
+            throw new \SimpleSAML\Error\Exception("'%replace' must be set if 'replacement' is null.");
         }
 
         if ($this->replace && $this->remove) {
-            throw new SimpleSAML_Error_Exception("'%replace' and '%remove' cannot be used together.");
+            throw new \SimpleSAML\Error\Exception("'%replace' and '%remove' cannot be used together.");
         }
 
         if (empty($this->target)) {
@@ -119,7 +124,7 @@ class sspmod_core_Auth_Process_AttributeAlter extends SimpleSAML_Auth_Processing
         }
 
         if ($this->subject !== $this->target && $this->remove) {
-            throw new SimpleSAML_Error_Exception("Cannot use '%remove' when 'target' is different than 'subject'.");
+            throw new \SimpleSAML\Error\Exception("Cannot use '%remove' when 'target' is different than 'subject'.");
         }
 
         if (!array_key_exists($this->subject, $attributes)) {
@@ -127,27 +132,29 @@ class sspmod_core_Auth_Process_AttributeAlter extends SimpleSAML_Auth_Processing
             return;
         }
 
-        if ($this->replace) { // replace the whole value
+        if ($this->replace) {
+            // replace the whole value
             foreach ($attributes[$this->subject] as &$value) {
-                $matches = array();
+                $matches = [];
                 if (preg_match($this->pattern, $value, $matches) > 0) {
                     $new_value = $matches[0];
 
-                    if ($this->replacement !== FALSE) {
+                    if ($this->replacement !== false) {
                         $new_value = $this->replacement;
                     }
 
                     if ($this->subject === $this->target) {
                         $value = $new_value;
                     } else {
-                        $attributes[$this->target] = array($new_value);
+                        $attributes[$this->target] = [$new_value];
                     }
                 }
             }
-        } elseif ($this->remove) { // remove the whole value
-            $removedAttrs = array();
+        } elseif ($this->remove) {
+            // remove the whole value
+            $removedAttrs = [];
             foreach ($attributes[$this->subject] as $value) {
-                $matches = array();
+                $matches = [];
                 if (preg_match($this->pattern, $value, $matches) > 0) {
                     $removedAttrs[] = $value;
                 }
@@ -157,10 +164,12 @@ class sspmod_core_Auth_Process_AttributeAlter extends SimpleSAML_Auth_Processing
             if (empty($attributes[$this->target])) {
                 unset($attributes[$this->target]);
             }
-        } else { // replace only the part that matches
+        } else {
+            // replace only the part that matches
             if ($this->subject === $this->target) {
                 $attributes[$this->target] = preg_replace(
-                    $this->pattern, $this->replacement,
+                    $this->pattern,
+                    $this->replacement,
                     $attributes[$this->subject]
                 );
             } else {
