@@ -61,10 +61,10 @@ class OAuthToken
      */
     public function to_string()
     {
-        return "oauth_token=" .
-        OAuthUtil::urlencode_rfc3986($this->key) .
-        "&oauth_token_secret=" .
-        OAuthUtil::urlencode_rfc3986($this->secret) .
+        return "oauth_token=".
+        OAuthUtil::urlencode_rfc3986($this->key).
+        "&oauth_token_secret=".
+        OAuthUtil::urlencode_rfc3986($this->secret).
         "&oauth_callback_confirmed=true";
     }
 
@@ -148,10 +148,10 @@ class OAuthSignatureMethod_HMAC_SHA1 extends OAuthSignatureMethod
         $base_string = $request->get_signature_base_string();
         $request->base_string = $base_string;
 
-        $key_parts = array(
+        $key_parts = [
             $consumer->secret,
             ($token) ? $token->secret : ""
-        );
+        ];
 
         $key_parts = OAuthUtil::urlencode_rfc3986($key_parts);
         $key = implode('&', $key_parts);
@@ -183,10 +183,10 @@ class OAuthSignatureMethod_PLAINTEXT extends OAuthSignatureMethod
      */
     public function build_signature($request, $consumer, $token)
     {
-        $key_parts = array(
+        $key_parts = [
             $consumer->secret,
             ($token) ? $token->secret : ""
-        );
+        ];
 
         $key_parts = OAuthUtil::urlencode_rfc3986($key_parts);
         $key = implode('&', $key_parts);
@@ -279,7 +279,7 @@ class OAuthRequest
 
     public function __construct($http_method, $http_url, $parameters = null)
     {
-        $parameters = ($parameters) ? $parameters : array();
+        $parameters = ($parameters) ? $parameters : [];
         $parameters = array_merge(OAuthUtil::parse_parameters(parse_url($http_url, PHP_URL_QUERY)), $parameters);
         $this->parameters = $parameters;
         $this->http_method = $http_method;
@@ -295,10 +295,10 @@ class OAuthRequest
         $scheme = (!isset($_SERVER['HTTPS']) || $_SERVER['HTTPS'] != "on")
             ? 'http'
             : 'https';
-        $http_url = ($http_url) ? $http_url : $scheme .
-            '://' . $_SERVER['SERVER_NAME'] .
-            ':' .
-            $_SERVER['SERVER_PORT'] .
+        $http_url = ($http_url) ? $http_url : $scheme.
+            '://'.$_SERVER['SERVER_NAME'].
+            ':'.
+            $_SERVER['SERVER_PORT'].
             $_SERVER['REQUEST_URI'];
         $http_method = ($http_method) ? $http_method : $_SERVER['REQUEST_METHOD'];
 
@@ -316,9 +316,8 @@ class OAuthRequest
             // It's a POST request of the proper content-type, so parse POST
             // parameters and add those overriding any duplicates from GET
             if ($http_method == "POST"
-                &&  isset($request_headers['Content-Type'])
-                && strstr($request_headers['Content-Type'],
-                    'application/x-www-form-urlencoded')
+                && isset($request_headers['Content-Type'])
+                && strstr($request_headers['Content-Type'], 'application/x-www-form-urlencoded')
             ) {
                 $post_data = OAuthUtil::parse_parameters(
                     file_get_contents(self::$POST_INPUT)
@@ -328,13 +327,14 @@ class OAuthRequest
 
             // We have a Authorization-header with OAuth data. Parse the header
             // and add those overriding any duplicates from GET or POST
-            if (isset($request_headers['Authorization']) && substr($request_headers['Authorization'], 0, 6) == 'OAuth ') {
+            if (isset($request_headers['Authorization'])
+                && substr($request_headers['Authorization'], 0, 6) == 'OAuth '
+            ) {
                 $header_parameters = OAuthUtil::split_header(
                     $request_headers['Authorization']
                 );
                 $parameters = array_merge($parameters, $header_parameters);
             }
-
         }
 
         return new OAuthRequest($http_method, $http_url, $parameters);
@@ -345,13 +345,14 @@ class OAuthRequest
      */
     public static function from_consumer_and_token($consumer, $token, $http_method, $http_url, $parameters = null)
     {
-        $parameters = ($parameters) ?  $parameters : array();
-        $defaults = array("oauth_version" => OAuthRequest::$version,
-                          "oauth_nonce" => OAuthRequest::generate_nonce(),
-                          "oauth_timestamp" => OAuthRequest::generate_timestamp(),
-                          "oauth_consumer_key" => $consumer->key);
-        if ($token)
+        $parameters = ($parameters) ? $parameters : [];
+        $defaults = ["oauth_version" => OAuthRequest::$version,
+                            "oauth_nonce" => OAuthRequest::generate_nonce(),
+                            "oauth_timestamp" => OAuthRequest::generate_timestamp(),
+                            "oauth_consumer_key" => $consumer->key];
+        if ($token) {
             $defaults['oauth_token'] = $token->key;
+        }
 
         $parameters = array_merge($defaults, $parameters);
 
@@ -365,7 +366,7 @@ class OAuthRequest
             if (is_scalar($this->parameters[$name])) {
                 // This is the first duplicate, so transform scalar (string)
                 // into an array so we can add the duplicates
-                $this->parameters[$name] = array($this->parameters[$name]);
+                $this->parameters[$name] = [$this->parameters[$name]];
             }
 
             $this->parameters[$name][] = $value;
@@ -416,11 +417,11 @@ class OAuthRequest
      */
     public function get_signature_base_string()
     {
-        $parts = array(
+        $parts = [
             $this->get_normalized_http_method(),
             $this->get_normalized_http_url(),
             $this->get_signable_parameters()
-        );
+        ];
 
         $parts = OAuthUtil::urlencode_rfc3986($parts);
 
@@ -483,7 +484,7 @@ class OAuthRequest
     {
         $first = true;
         if ($realm) {
-            $out = 'Authorization: OAuth realm="' . OAuthUtil::urlencode_rfc3986($realm) . '"';
+            $out = 'Authorization: OAuth realm="'.OAuthUtil::urlencode_rfc3986($realm).'"';
             $first = false;
         } else {
             $out = 'Authorization: OAuth';
@@ -497,9 +498,9 @@ class OAuthRequest
                 throw new OAuthException('Arrays not supported in headers');
             }
             $out .= ($first) ? ' ' : ',';
-            $out .= OAuthUtil::urlencode_rfc3986($k) .
-                '="' .
-                OAuthUtil::urlencode_rfc3986($v) .
+            $out .= OAuthUtil::urlencode_rfc3986($k).
+                '="'.
+                OAuthUtil::urlencode_rfc3986($v).
                 '"';
             $first = false;
         }
@@ -545,15 +546,15 @@ class OAuthRequest
         $mt = microtime();
         $rand = mt_rand();
 
-        return md5($mt . $rand); // md5s look nicer than numbers
+        return md5($mt.$rand); // md5s look nicer than numbers
     }
 }
 
 class OAuthServer
 {
     protected $timestamp_threshold = 300; // in seconds, five minutes
-    protected $version = '1.0';             // hi blaine
-    protected $signature_methods = array();
+    protected $version = '1.0'; // hi blaine
+    protected $signature_methods = [];
 
     protected $data_store;
 
@@ -576,14 +577,14 @@ class OAuthServer
      */
     public function fetch_request_token(&$request)
     {
-        $this->get_version($request);
+        $this->getVersion($request);
 
-        $consumer = $this->get_consumer($request);
+        $consumer = $this->getConsumer($request);
 
         // no token required for the initial token request
-        $token = NULL;
+        $token = null;
 
-        $this->check_signature($request, $consumer, $token);
+        $this->checkSignature($request, $consumer, $token);
 
         // Rev A change
         $callback = $request->get_parameter('oauth_callback');
@@ -598,14 +599,14 @@ class OAuthServer
      */
     public function fetch_access_token(&$request)
     {
-        $this->get_version($request);
+        $this->getVersion($request);
 
-        $consumer = $this->get_consumer($request);
+        $consumer = $this->getConsumer($request);
 
         // requires authorized request token
-        $token = $this->get_token($request, $consumer, "request");
+        $token = $this->getToken($request, $consumer, "request");
 
-        $this->check_signature($request, $consumer, $token);
+        $this->checkSignature($request, $consumer, $token);
 
         // Rev A change
         $verifier = $request->get_parameter('oauth_verifier');
@@ -619,18 +620,18 @@ class OAuthServer
      */
     public function verify_request(&$request)
     {
-        $this->get_version($request);
-        $consumer = $this->get_consumer($request);
-        $token = $this->get_token($request, $consumer, "access");
-        $this->check_signature($request, $consumer, $token);
-        return array($consumer, $token);
+        $this->getVersion($request);
+        $consumer = $this->getConsumer($request);
+        $token = $this->getToken($request, $consumer, "access");
+        $this->checkSignature($request, $consumer, $token);
+        return [$consumer, $token];
     }
 
     // Internals from here
     /**
      * version 1
      */
-    private function get_version(&$request)
+    private function getVersion(&$request)
     {
         $version = $request->get_parameter("oauth_version");
         if (!$version) {
@@ -647,11 +648,11 @@ class OAuthServer
     /**
      * figure out the signature with some defaults
      */
-    private function get_signature_method($request)
+    private function getSignatureMethod($request)
     {
         $signature_method = $request instanceof OAuthRequest
             ? $request->get_parameter("oauth_signature_method")
-            : NULL;
+            : null;
 
         if (!$signature_method) {
             // According to chapter 7 ("Accessing Protected Ressources") the signature-method
@@ -659,11 +660,10 @@ class OAuthServer
             throw new OAuthException('No signature method parameter. This parameter is required');
         }
 
-        if (!in_array($signature_method,
-            array_keys($this->signature_methods))) {
+        if (!in_array($signature_method, array_keys($this->signature_methods))) {
             throw new OAuthException(
-                "Signature method '$signature_method' not supported " .
-                "try one of the following: " .
+                "Signature method '$signature_method' not supported ".
+                "try one of the following: ".
                 implode(", ", array_keys($this->signature_methods))
             );
         }
@@ -673,11 +673,11 @@ class OAuthServer
     /**
      * try to find the consumer for the provided request's consumer key
      */
-    private function get_consumer($request)
+    private function getConsumer($request)
     {
         $consumer_key = $request instanceof OAuthRequest
             ? $request->get_parameter("oauth_consumer_key")
-            : NULL;
+            : null;
 
         if (!$consumer_key) {
             throw new OAuthException("Invalid consumer key");
@@ -694,21 +694,18 @@ class OAuthServer
     /**
      * try to find the token for the provided request's token key
      */
-    private function get_token($request, $consumer, $token_type="access")
+    private function getToken($request, $consumer, $token_type = "access")
     {
         $token_field = $request instanceof OAuthRequest
             ? $request->get_parameter('oauth_token')
             : null;
 
         if (!empty($token_field)) {
-            $token = $this->data_store->lookup_token(
-                $consumer, $token_type, $token_field
-            );
+            $token = $this->data_store->lookup_token($consumer, $token_type, $token_field);
             if (!$token) {
-                throw new OAuthException("Invalid $token_type token: $token_field");
+                throw new OAuthException('Invalid '.$token_type.' token: '.$token_field);
             }
-        }
-        else {
+        } else {
             $token = new OAuthToken('', '');
         }
         return $token;
@@ -718,7 +715,7 @@ class OAuthServer
      * all-in-one function to check the signature on a request
      * should guess the signature method appropriately
      */
-    private function check_signature($request, $consumer, $token)
+    private function checkSignature($request, $consumer, $token)
     {
         // this should probably be in a different method
         $timestamp = $request instanceof OAuthRequest
@@ -728,13 +725,13 @@ class OAuthServer
             ? $request->get_parameter('oauth_nonce')
             : null;
 
-        $this->check_timestamp($timestamp);
-        $this->check_nonce($consumer, $token, $nonce, $timestamp);
+        $this->checkTimestamp($timestamp);
+        $this->checkNonce($consumer, $token, $nonce, $timestamp);
 
-        $signature_method = $this->get_signature_method($request);
+        $signature_method = $this->getSignatureMethod($request);
 
         $signature = $request->get_parameter('oauth_signature');
-        $valid_sig = $signature_method->check_signature(
+        $valid_sig = $signature_method->checkSignature(
             $request,
             $consumer,
             $token,
@@ -749,7 +746,7 @@ class OAuthServer
     /**
      * check that the timestamp is new enough
      */
-    private function check_timestamp($timestamp)
+    private function checkTimestamp($timestamp)
     {
         if (!$timestamp) {
             throw new OAuthException(
@@ -769,7 +766,7 @@ class OAuthServer
     /**
      * check that the nonce is not repeated
      */
-    private function check_nonce($consumer, $token, $nonce, $timestamp)
+    private function checkNonce($consumer, $token, $nonce, $timestamp)
     {
         if (!$nonce) {
             throw new OAuthException(
@@ -819,7 +816,6 @@ class OAuthDataStore
         // is authorized
         // should also invalidate the request token
     }
-
 }
 
 class OAuthUtil
@@ -827,8 +823,8 @@ class OAuthUtil
     public static function urlencode_rfc3986($input)
     {
         if (is_array($input)) {
-            return array_map(array('OAuthUtil', 'urlencode_rfc3986'), $input);
-        } else if (is_scalar($input)) {
+            return array_map(['OAuthUtil', 'urlencode_rfc3986'], $input);
+        } elseif (is_scalar($input)) {
             return str_replace(
                 '+',
                 ' ',
@@ -855,8 +851,12 @@ class OAuthUtil
     //                  see http://code.google.com/p/oauth/issues/detail?id=163
     public static function split_header($header, $only_allow_oauth_parameters = true)
     {
-        $params = array();
-        if (preg_match_all('/('.($only_allow_oauth_parameters ? 'oauth_' : '').'[a-z_-]*)=(:?"([^"]*)"|([^,]*))/', $header, $matches)) {
+        $params = [];
+        if (preg_match_all(
+            '/('.($only_allow_oauth_parameters ? 'oauth_' : '').'[a-z_-]*)=(:?"([^"]*)"|([^,]*))/',
+            $header,
+            $matches
+        )) {
             foreach ($matches[1] as $i => $h) {
                 $params[$h] = OAuthUtil::urldecode_rfc3986(empty($matches[3][$i]) ? $matches[4][$i] : $matches[3][$i]);
             }
@@ -879,7 +879,7 @@ class OAuthUtil
             // we always want the keys to be Cased-Like-This and arh()
             // returns the headers in the same case as they are in the
             // request
-            $out = array();
+            $out = [];
             foreach ($headers as $key => $value) {
                 $key = str_replace(
                     " ",
@@ -891,7 +891,7 @@ class OAuthUtil
         } else {
             // otherwise we don't have apache and are just going to have to hope
             // that $_SERVER actually contains what we need
-            $out = array();
+            $out = [];
             if (isset($_SERVER['CONTENT_TYPE'])) {
                 $out['Content-Type'] = $_SERVER['CONTENT_TYPE'];
             }
@@ -926,12 +926,12 @@ class OAuthUtil
     public static function parse_parameters($input)
     {
         if (!isset($input) || !$input) {
-            return array();
+            return [];
         }
 
         $pairs = explode('&', $input);
 
-        $parsed_parameters = array();
+        $parsed_parameters = [];
         foreach ($pairs as $pair) {
             $split = explode('=', $pair, 2);
             $parameter = OAuthUtil::urldecode_rfc3986($split[0]);
@@ -944,7 +944,7 @@ class OAuthUtil
                 if (is_scalar($parsed_parameters[$parameter])) {
                     // This is the first duplicate, so transform scalar (string) into an array
                     // so we can add the duplicates
-                    $parsed_parameters[$parameter] = array($parsed_parameters[$parameter]);
+                    $parsed_parameters[$parameter] = [$parsed_parameters[$parameter]];
                 }
 
                 $parsed_parameters[$parameter][] = $value;
@@ -970,7 +970,7 @@ class OAuthUtil
         // Ref: Spec: 9.1.1 (1)
         uksort($params, 'strcmp');
 
-        $pairs = array();
+        $pairs = [];
         foreach ($params as $parameter => $value) {
             if (is_array($value)) {
                 // If two or more parameters share the same name, they are sorted by their value
@@ -978,10 +978,10 @@ class OAuthUtil
                 // June 12th, 2010 - changed to sort because of issue 164 by hidetaka
                 sort($value, SORT_STRING);
                 foreach ($value as $duplicate_value) {
-                    $pairs[] = $parameter . '=' . $duplicate_value;
+                    $pairs[] = $parameter.'='.$duplicate_value;
                 }
             } else {
-                $pairs[] = $parameter . '=' . $value;
+                $pairs[] = $parameter.'='.$value;
             }
         }
         // For each parameter, the name is separated from the corresponding value by an '=' character (ASCII code 61)
