@@ -4,7 +4,7 @@ namespace SimpleSAML\Test\Utils;
 
 use PHPUnit\Framework\TestCase;
 use SimpleSAML\Utils\Crypto;
-use \SimpleSAML_Configuration as Configuration;
+use \SimpleSAML\Configuration;
 
 use \org\bovigo\vfs\vfsStream;
 
@@ -21,9 +21,9 @@ class CryptoTest extends TestCase
         $this->root = vfsStream::setup(
             self::ROOTDIRNAME,
             null,
-            array(
-                self::DEFAULTCERTDIR => array(),
-            )
+            [
+                self::DEFAULTCERTDIR => [],
+            ]
         );
         $this->root_directory = vfsStream::url(self::ROOTDIRNAME);
         $this->certdir = $this->root_directory.DIRECTORY_SEPARATOR.self::DEFAULTCERTDIR;
@@ -34,14 +34,14 @@ class CryptoTest extends TestCase
      *
      * @expectedException \InvalidArgumentException
      *
-     * @covers \SimpleSAML\Utils\Crypto::_aesDecrypt
+     * @covers \SimpleSAML\Utils\Crypto::aesDecrypt
      */
     public function testAesDecryptBadInput()
     {
         $m = new \ReflectionMethod('\SimpleSAML\Utils\Crypto', '_aesDecrypt');
         $m->setAccessible(true);
 
-        $m->invokeArgs(null, array(array(), 'SECRET'));
+        $m->invokeArgs(null, [[], 'SECRET']);
     }
 
 
@@ -50,14 +50,14 @@ class CryptoTest extends TestCase
      *
      * @expectedException \InvalidArgumentException
      *
-     * @covers \SimpleSAML\Utils\Crypto::_aesEncrypt
+     * @covers \SimpleSAML\Utils\Crypto::aesEncrypt
      */
     public function testAesEncryptBadInput()
     {
         $m = new \ReflectionMethod('\SimpleSAML\Utils\Crypto', '_aesEncrypt');
         $m->setAccessible(true);
 
-        $m->invokeArgs(null, array(array(), 'SECRET'));
+        $m->invokeArgs(null, [[], 'SECRET']);
     }
 
 
@@ -65,12 +65,12 @@ class CryptoTest extends TestCase
      * Test that aesDecrypt() works properly, being able to decrypt some previously known (and correct)
      * ciphertext.
      *
-     * @covers \SimpleSAML\Utils\Crypto::_aesDecrypt
+     * @covers \SimpleSAML\Utils\Crypto::aesDecrypt
      */
     public function testAesDecrypt()
     {
         if (!extension_loaded('openssl')) {
-            $this->setExpectedException('\SimpleSAML_Error_Exception');
+            $this->setExpectedException('\SimpleSAML\Error\Exception');
         }
 
         $secret = 'SUPER_SECRET_SALT';
@@ -79,20 +79,20 @@ class CryptoTest extends TestCase
 
         $plaintext = 'SUPER_SECRET_TEXT';
         $ciphertext = 'uR2Yu0r4itInKx91D/l9y/08L5CIQyev9nAr27fh3Sshous4vbXRRcMcjqHDOrquD+2vqLyw7ygnbA9jA9TpB4hLZocvAWcTN8tyO82hiSY=';
-        $this->assertEquals($plaintext, $m->invokeArgs(null, array(base64_decode($ciphertext), $secret)));
+        $this->assertEquals($plaintext, $m->invokeArgs(null, [base64_decode($ciphertext), $secret]));
     }
 
 
     /**
      * Test that aesEncrypt() produces ciphertexts that aesDecrypt() can decrypt.
      *
-     * @covers \SimpleSAML\Utils\Crypto::_aesDecrypt
-     * @covers \SimpleSAML\Utils\Crypto::_aesEncrypt
+     * @covers \SimpleSAML\Utils\Crypto::aesDecrypt
+     * @covers \SimpleSAML\Utils\Crypto::aesEncrypt
      */
     public function testAesEncrypt()
     {
         if (!extension_loaded('openssl')) {
-            $this->setExpectedException('\SimpleSAML_Error_Exception');
+            $this->setExpectedException('\SimpleSAML\Error\Exception');
         }
 
         $secret = 'SUPER_SECRET_SALT';
@@ -102,8 +102,8 @@ class CryptoTest extends TestCase
         $d->setAccessible(true);
 
         $original_plaintext = 'SUPER_SECRET_TEXT';
-        $ciphertext = $e->invokeArgs(null, array($original_plaintext, $secret));
-        $decrypted_plaintext = $d->invokeArgs(null, array($ciphertext, $secret));
+        $ciphertext = $e->invokeArgs(null, [$original_plaintext, $secret]);
+        $decrypted_plaintext = $d->invokeArgs(null, [$ciphertext, $secret]);
         $this->assertEquals($original_plaintext, $decrypted_plaintext);
     }
 
@@ -157,6 +157,7 @@ PHP;
 
     /**
      * @covers \SimpleSAML\Utils\Crypto::pwHash
+     * @deprecated To be removed for 2.0
      */
     public function testGoodPwHash()
     {
@@ -174,8 +175,10 @@ PHP;
         $this->assertEquals($expected, $res);
     }
 
+
     /**
      * @covers \SimpleSAML\Utils\Crypto::pwHash
+     * @deprecated To be removed for 2.0
      */
     public function testGoodSaltedPwHash()
     {
@@ -195,7 +198,8 @@ PHP;
     }
 
     /**
-     * @expectedException \SimpleSAML_Error_Exception
+     * @expectedException \SimpleSAML\Error\Exception
+     * @deprecated To be removed for 2.0
      *
      * @covers \SimpleSAML\Utils\Crypto::pwHash
      */
@@ -211,6 +215,35 @@ PHP;
      * @covers \SimpleSAML\Utils\Crypto::pwValid
      */
     public function testGoodPwValid()
+    {
+        $pw = "password";
+
+        $hash = Crypto::pwHash($pw);
+        $res = Crypto::pwValid($hash, $pw);
+
+        $this->assertTrue($res);
+    }
+
+    /**
+     * @covers \SimpleSAML\Utils\Crypto::pwValid
+     */
+    public function testBadPwInvalid()
+    {
+        $pw = "password";
+        $pw2 = "password2";
+
+        $hash = Crypto::pwHash($pw);
+        $res = Crypto::pwValid($hash, $pw2);
+
+        $this->assertFalse($res);
+    }
+
+
+    /**
+     * @covers \SimpleSAML\Utils\Crypto::pwValid
+     * @deprecated To be removed for 2.0
+     */
+    public function testGoodPwValidOld()
     {
         $pw = "password";
         $algorithm = "SHA1";
@@ -223,6 +256,7 @@ PHP;
 
     /**
      * @covers \SimpleSAML\Utils\Crypto::pwValid
+     * @deprecated To be removed for 2.0
      */
     public function testGoodSaltedPwValid()
     {
@@ -237,13 +271,13 @@ PHP;
     }
 
     /**
-     * @expectedException \SimpleSAML_Error_Exception
+     * @expectedException \SimpleSAML\Error\Exception
+     * @deprecated To be removed for 2.0
      *
      * @covers \SimpleSAML\Utils\Crypto::pwValid
      */
     public function testBadHashAlgorithmValid()
     {
-        $pw = "password";
         $algorithm = "wtf";
         $hash = "{".$algorithm."}B64STRING";
 
@@ -271,13 +305,13 @@ PHP;
     }
 
     /**
-     * @expectedException \SimpleSAML_Error_Exception
+     * @expectedException \SimpleSAML\Error\Exception
      *
      * @covers \SimpleSAML\Utils\Crypto::loadPrivateKey
      */
     public function testLoadPrivateKeyRequiredMetadataMissing()
     {
-        $config = new Configuration(array(), 'test');
+        $config = new Configuration([], 'test');
         $required = true;
 
         Crypto::loadPrivateKey($config, $required);
@@ -288,7 +322,7 @@ PHP;
      */
     public function testLoadPrivateKeyNotRequiredMetadataMissing()
     {
-        $config = new Configuration(array(), 'test');
+        $config = new Configuration([], 'test');
         $required = false;
 
         $res = Crypto::loadPrivateKey($config, $required);
@@ -297,13 +331,13 @@ PHP;
     }
 
     /**
-     * @expectedException \SimpleSAML_Error_Exception
+     * @expectedException \SimpleSAML\Error\Exception
      *
      * @covers \SimpleSAML\Utils\Crypto::loadPrivateKey
      */
     public function testLoadPrivateKeyMissingFile()
     {
-        $config = new Configuration(array('privatekey' => 'nonexistant'), 'test');
+        $config = new Configuration(['privatekey' => 'nonexistant'], 'test');
 
         Crypto::loadPrivateKey($config, false, '', true);
     }
@@ -315,13 +349,13 @@ PHP;
     {
         $filename = $this->certdir.DIRECTORY_SEPARATOR.'key';
         $data = 'data';
-        $config = new Configuration(array('privatekey' => $filename), 'test');
+        $config = new Configuration(['privatekey' => $filename], 'test');
         $full_path = true;
 
         file_put_contents($filename, $data);
 
         $res = Crypto::loadPrivateKey($config, false, '', $full_path);
-        $expected = array('PEM' => $data);
+        $expected = ['PEM' => $data];
 
         $this->assertEquals($expected, $res);
     }
@@ -335,10 +369,10 @@ PHP;
         $filename = $this->certdir.DIRECTORY_SEPARATOR.'key';
         $data = 'data';
         $config = new Configuration(
-            array(
+            [
                 'privatekey' => $filename,
                 'privatekey_pass' => $password,
-            ),
+            ],
             'test'
         );
         $full_path = true;
@@ -346,7 +380,7 @@ PHP;
         file_put_contents($filename, $data);
 
         $res = Crypto::loadPrivateKey($config, false, '', $full_path);
-        $expected = array('PEM' => $data, 'password' => $password);
+        $expected = ['PEM' => $data, 'password' => $password];
 
         $this->assertEquals($expected, $res);
     }
@@ -361,10 +395,10 @@ PHP;
         $filename = $this->certdir.DIRECTORY_SEPARATOR.'key';
         $data = 'data';
         $config = new Configuration(
-            array(
+            [
                 $prefix.'privatekey' => $filename,
                 $prefix.'privatekey_pass' => $password,
-            ),
+            ],
             'test'
         );
         $full_path = true;
@@ -372,19 +406,19 @@ PHP;
         file_put_contents($filename, $data);
 
         $res = Crypto::loadPrivateKey($config, false, $prefix, $full_path);
-        $expected = array('PEM' => $data, 'password' => $password);
+        $expected = ['PEM' => $data, 'password' => $password];
 
         $this->assertEquals($expected, $res);
     }
 
     /**
-     * @expectedException \SimpleSAML_Error_Exception
+     * @expectedException \SimpleSAML\Error\Exception
      *
      * @covers \SimpleSAML\Utils\Crypto::loadPublicKey
      */
     public function testLoadPublicKeyRequiredMetadataMissing()
     {
-        $config = new Configuration(array(), 'test');
+        $config = new Configuration([], 'test');
         $required = true;
 
         Crypto::loadPublicKey($config, $required);
@@ -395,7 +429,7 @@ PHP;
      */
     public function testLoadPublicKeyNotRequiredMetadataMissing()
     {
-        $config = new Configuration(array(), 'test');
+        $config = new Configuration([], 'test');
         $required = false;
 
         $res = Crypto::loadPublicKey($config, $required);
@@ -409,10 +443,10 @@ PHP;
     public function testLoadPublicKeyFingerprintBasicString()
     {
         $fingerprint = 'fingerprint';
-        $config = new Configuration(array('certFingerprint' => $fingerprint), 'test');
+        $config = new Configuration(['certFingerprint' => $fingerprint], 'test');
 
         $res = Crypto::loadPublicKey($config);
-        $expected = array('certFingerprint' => array($fingerprint));
+        $expected = ['certFingerprint' => [$fingerprint]];
 
         $this->assertEquals($expected, $res);
     }
@@ -425,17 +459,17 @@ PHP;
         $fingerprint1 = 'fingerprint1';
         $fingerprint2 = 'fingerprint2';
         $config = new Configuration(
-            array(
-                'certFingerprint' => array(
+            [
+                'certFingerprint' => [
                     $fingerprint1,
                     $fingerprint2
-                ),
-            ),
+                ],
+            ],
             'test'
         );
 
         $res = Crypto::loadPublicKey($config);
-        $expected = array('certFingerprint' => array($fingerprint1, $fingerprint2));
+        $expected = ['certFingerprint' => [$fingerprint1, $fingerprint2]];
 
         $this->assertEquals($expected, $res);
     }
@@ -446,10 +480,10 @@ PHP;
     public function testLoadPublicKeyFingerprintLowercase()
     {
         $fingerprint = 'FINGERPRINT';
-        $config = new Configuration(array('certFingerprint' => $fingerprint), 'test');
+        $config = new Configuration(['certFingerprint' => $fingerprint], 'test');
 
         $res = Crypto::loadPublicKey($config);
-        $expected = array('certFingerprint' => array(strtolower($fingerprint)));
+        $expected = ['certFingerprint' => [strtolower($fingerprint)]];
 
         $this->assertEquals($expected, $res);
     }
@@ -460,10 +494,10 @@ PHP;
     public function testLoadPublicKeyFingerprintRemoveColons()
     {
         $fingerprint = 'f:i:n:g:e:r:p:r:i:n:t';
-        $config = new Configuration(array('certFingerprint' => $fingerprint), 'test');
+        $config = new Configuration(['certFingerprint' => $fingerprint], 'test');
 
         $res = Crypto::loadPublicKey($config);
-        $expected = array('certFingerprint' => array(str_replace(':', '', $fingerprint)));
+        $expected = ['certFingerprint' => [str_replace(':', '', $fingerprint)]];
 
         $this->assertEquals($expected, $res);
     }
@@ -474,15 +508,15 @@ PHP;
     public function testLoadPublicKeyNotX509Certificate()
     {
         $config = new Configuration(
-            array(
-                'keys' => array(
-                    array(
+            [
+                'keys' => [
+                    [
                         'X509Certificate' => '',
                         'type' => 'NotX509Certificate',
                         'signing' => true
-                    ),
-                ),
-            ),
+                    ],
+                ],
+            ],
             'test'
         );
 
@@ -497,15 +531,15 @@ PHP;
     public function testLoadPublicKeyNotSigning()
     {
         $config = new Configuration(
-            array(
-                'keys' => array(
-                    array(
+            [
+                'keys' => [
+                    [
                         'X509Certificate' => '',
                         'type' => 'X509Certificate',
                         'signing' => false
-                    ),
-                ),
-            ),
+                    ],
+                ],
+            ],
             'test'
         );
 
@@ -521,15 +555,15 @@ PHP;
     {
         $x509certificate = 'x509certificate';
         $config = new Configuration(
-            array(
-                'keys' => array(
-                    array(
+            [
+                'keys' => [
+                    [
                         'X509Certificate' => $x509certificate,
                         'type' => 'X509Certificate',
                         'signing' => true
-                    ),
-                ),
-            ),
+                    ],
+                ],
+            ],
             'test'
         );
 
