@@ -34,26 +34,26 @@ class AttributeValueMapTest extends TestCase
      */
     public function testBasic()
     {
-        $config = array(
+        $config = [
             'sourceattribute' => 'memberOf',
             'targetattribute' => 'eduPersonAffiliation',
-            'values' => array(
-                'member' => array(
+            'values' => [
+                'member' => [
                     'theGroup',
                     'otherGroup',
-                ),
-            ),
-        );
-        $request = array(
-            'Attributes' => array(
-                'memberOf' => array('theGroup'),
-            ),
-        );
+                ],
+            ],
+        ];
+        $request = [
+            'Attributes' => [
+                'memberOf' => ['theGroup'],
+            ],
+        ];
         $result = self::processFilter($config, $request);
         $attributes = $result['Attributes'];
         $this->assertArrayNotHasKey('memberOf', $attributes);
         $this->assertArrayHasKey('eduPersonAffiliation', $attributes);
-        $this->assertEquals($attributes['eduPersonAffiliation'], array('member'));
+        $this->assertEquals($attributes['eduPersonAffiliation'], ['member']);
     }
 
 
@@ -65,27 +65,27 @@ class AttributeValueMapTest extends TestCase
      */
     public function testNoDuplicates()
     {
-        $config = array(
+        $config = [
             'sourceattribute' => 'memberOf',
             'targetattribute' => 'eduPersonAffiliation',
-            'values' => array(
-                'member' => array(
+            'values' => [
+                'member' => [
                     'theGroup',
                     'otherGroup',
-                ),
-            ),
-        );
-        $request = array(
-            'Attributes' => array(
-                'memberOf' => array('theGroup', 'otherGroup'),
-                'eduPersonAffiliation' => array('member', 'someValue'),
-            ),
-        );
+                ],
+            ],
+        ];
+        $request = [
+            'Attributes' => [
+                'memberOf' => ['theGroup', 'otherGroup'],
+                'eduPersonAffiliation' => ['member', 'someValue'],
+            ],
+        ];
         $result = self::processFilter($config, $request);
         $attributes = $result['Attributes'];
         $this->assertArrayNotHasKey('memberOf', $attributes);
         $this->assertArrayHasKey('eduPersonAffiliation', $attributes);
-        $this->assertEquals($attributes['eduPersonAffiliation'], array('member', 'someValue'));
+        $this->assertEquals($attributes['eduPersonAffiliation'], ['member', 'someValue']);
     }
 
 
@@ -97,28 +97,28 @@ class AttributeValueMapTest extends TestCase
      */
     public function testReplace()
     {
-        $config = array(
+        $config = [
             'sourceattribute' => 'memberOf',
             'targetattribute' => 'eduPersonAffiliation',
             '%replace',
-            'values' => array(
-                'member' => array(
+            'values' => [
+                'member' => [
                     'theGroup',
                     'otherGroup',
-                ),
-            ),
-        );
-        $request = array(
-            'Attributes' => array(
-                'memberOf' => array('theGroup'),
-                'eduPersonAffiliation' => array('someValue'),
-            ),
-        );
+                ],
+            ],
+        ];
+        $request = [
+            'Attributes' => [
+                'memberOf' => ['theGroup'],
+                'eduPersonAffiliation' => ['someValue'],
+            ],
+        ];
         $result = self::processFilter($config, $request);
         $attributes = $result['Attributes'];
         $this->assertArrayNotHasKey('memberOf', $attributes);
         $this->assertArrayHasKey('eduPersonAffiliation', $attributes);
-        $this->assertEquals($attributes['eduPersonAffiliation'], array('member'));
+        $this->assertEquals($attributes['eduPersonAffiliation'], ['member']);
     }
 
 
@@ -130,28 +130,28 @@ class AttributeValueMapTest extends TestCase
      */
     public function testKeep()
     {
-        $config = array(
+        $config = [
             'sourceattribute' => 'memberOf',
             'targetattribute' => 'eduPersonAffiliation',
             '%keep',
-            'values' => array(
-                'member' => array(
+            'values' => [
+                'member' => [
                     'theGroup',
                     'otherGroup',
-                ),
-            ),
-        );
-        $request = array(
-            'Attributes' => array(
-                'memberOf' => array('theGroup'),
-                'eduPersonAffiliation' => array('someValue'),
-            ),
-        );
+                ],
+            ],
+        ];
+        $request = [
+            'Attributes' => [
+                'memberOf' => ['theGroup'],
+                'eduPersonAffiliation' => ['someValue'],
+            ],
+        ];
         $result = self::processFilter($config, $request);
         $attributes = $result['Attributes'];
         $this->assertArrayHasKey('memberOf', $attributes);
         $this->assertArrayHasKey('eduPersonAffiliation', $attributes);
-        $this->assertEquals($attributes['eduPersonAffiliation'], array('someValue','member'));
+        $this->assertEquals($attributes['eduPersonAffiliation'], ['someValue', 'member']);
     }
 
 
@@ -163,21 +163,21 @@ class AttributeValueMapTest extends TestCase
      */
     public function testUnknownFlag()
     {
-        $config = array(
+        $config = [
             '%test',
             'targetattribute' => 'affiliation',
             'sourceattribute' => 'memberOf',
-            'values' => array(
-                'member' => array(
+            'values' => [
+                'member' => [
                     'theGroup',
-                ),
-            ),
-        );
-        $request = array(
-            'Attributes' => array(
-                'memberOf' => array('theGroup'),
-            ),
-        );
+                ],
+            ],
+        ];
+        $request = [
+            'Attributes' => [
+                'memberOf' => ['theGroup'],
+            ],
+        ];
         $result = self::processFilter($config, $request);
         $this->assertArrayHasKey('affiliation', $result['Attributes']);
         $this->assertArrayNotHasKey('memberOf', $result['Attributes']);
@@ -195,19 +195,19 @@ class AttributeValueMapTest extends TestCase
      */
     public function testMissingSourceAttribute()
     {
-        $config = array(
+        $config = [
             'targetattribute' => 'affiliation',
-            'values' => array(
-                'member' => array(
+            'values' => [
+                'member' => [
                     'theGroup',
-                ),
-            ),
-        );
-        $request = array(
-            'Attributes' => array(
-                'memberOf' => array('theGroup'),
-            ),
-        );
+                ],
+            ],
+        ];
+        $request = [
+            'Attributes' => [
+                'memberOf' => ['theGroup'],
+            ],
+        ];
         self::processFilter($config, $request);
     }
 
@@ -222,19 +222,19 @@ class AttributeValueMapTest extends TestCase
      */
     public function testMissingTargetAttribute()
     {
-        $config = array(
+        $config = [
             'sourceattribute' => 'memberOf',
-            'values' => array(
-                'member' => array(
+            'values' => [
+                'member' => [
                     'theGroup',
-                ),
-            ),
-        );
-        $request = array(
-            'Attributes' => array(
-                'memberOf' => array('theGroup'),
-            ),
-        );
+                ],
+            ],
+        ];
+        $request = [
+            'Attributes' => [
+                'memberOf' => ['theGroup'],
+            ],
+        ];
         self::processFilter($config, $request);
     }
 }
