@@ -16,15 +16,15 @@ require_once('_include.php');
 
 try {
     // load SimpleSAMLphp configuration
-    $globalConfig = SimpleSAML_Configuration::getInstance();
+    $globalConfig = \SimpleSAML\Configuration::getInstance();
 
     // check if this module is enabled
     if (!$globalConfig->getBoolean('enable.authmemcookie', false)) {
-        throw new SimpleSAML_Error_Error('NOACCESS');
+        throw new \SimpleSAML\Error\Error('NOACCESS');
     }
 
     // load Auth MemCookie configuration
-    $amc = SimpleSAML_AuthMemCookie::getInstance();
+    $amc = \SimpleSAML\AuthMemCookie::getInstance();
 
     $sourceId = $amc->getAuthSource();
     $s = new \SimpleSAML\Auth\Simple($sourceId);
@@ -33,19 +33,19 @@ try {
     $s->requireAuth();
 
     // generate session id and save it in a cookie
-    $sessionID = SimpleSAML\Utils\Random::generateID();
+    $sessionID = \SimpleSAML\Utils\Random::generateID();
     $cookieName = $amc->getCookieName();
     \SimpleSAML\Utils\HTTP::setCookie($cookieName, $sessionID);
 
     // generate the authentication information
     $attributes = $s->getAttributes();
 
-    $authData = array();
+    $authData = [];
 
     // username
     $usernameAttr = $amc->getUsernameAttr();
     if (!array_key_exists($usernameAttr, $attributes)) {
-        throw new Exception(
+        throw new \Exception(
             "The user doesn't have an attribute named '".$usernameAttr.
             "'. This attribute is expected to contain the username."
         );
@@ -56,14 +56,14 @@ try {
     $groupsAttr = $amc->getGroupsAttr();
     if ($groupsAttr !== null) {
         if (!array_key_exists($groupsAttr, $attributes)) {
-            throw new Exception(
+            throw new \Exception(
                 "The user doesn't have an attribute named '".$groupsAttr.
                 "'. This attribute is expected to contain the groups the user is a member of."
             );
         }
         $authData['Groups'] = $attributes[$groupsAttr];
     } else {
-        $authData['Groups'] = array();
+        $authData['Groups'] = [];
     }
 
     $authData['RemoteIP'] = $_SERVER['REMOTE_ADDR'];
@@ -96,11 +96,11 @@ try {
     $memcache->set($sessionID, $data, 0, $expirationTime);
 
     // register logout handler
-    $session = SimpleSAML_Session::getSessionFromRequest();
-    $session->registerLogoutHandler($sourceId, 'SimpleSAML_AuthMemCookie', 'logoutHandler');
+    $session = \SimpleSAML\Session::getSessionFromRequest();
+    $session->registerLogoutHandler($sourceId, '\SimpleSAML\AuthMemCookie', 'logoutHandler');
 
     // redirect the user back to this page to signal that the login is completed
     \SimpleSAML\Utils\HTTP::redirectTrustedURL(\SimpleSAML\Utils\HTTP::getSelfURL());
-} catch (Exception $e) {
-    throw new SimpleSAML_Error_Error('CONFIG', $e);
+} catch (\Exception $e) {
+    throw new \SimpleSAML\Error\Error('CONFIG', $e);
 }
